@@ -1,4 +1,5 @@
-# library(RBaseX)
+library(RBaseX)
+library(testthat)
 
 skip_unless_socket_available <- function() {
     tryCatch({
